@@ -1,5 +1,8 @@
 package Finance::Currency::Convert::KlikBCA;
 
+our $DATE = '2015-07-10'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -7,8 +10,6 @@ use Log::Any '$log';
 use LWP::Simple;
 use Parse::Number::ID qw(parse_number_id);
 
-our $VERSION = '0.07'; # VERSION
-
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_currencies convert_currency);
 
@@ -148,7 +149,7 @@ sub convert_currency {
 }
 
 1;
-# ABSTRACT: Convert currencies using data from KlikBCA/BCA
+# ABSTRACT: Convert currency using KlikBCA
 
 __END__
 
@@ -158,11 +159,11 @@ __END__
 
 =head1 NAME
 
-Finance::Currency::Convert::KlikBCA - Convert currencies using data from KlikBCA/BCA
+Finance::Currency::Convert::KlikBCA - Convert currency using KlikBCA
 
 =head1 VERSION
 
-This document describes version 0.07 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2014-09-05.
+This document describes version 0.08 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2015-07-10.
 
 =head1 SYNOPSIS
 
@@ -207,9 +208,7 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (any)
+Return value:  (any)
 
 
 =head2 get_currencies() -> [status, msg, result, meta]
@@ -218,8 +217,6 @@ Extract data from KlikBCA/BCA page.
 
 No arguments.
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -229,15 +226,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
-=head1 TODO
-
-=over
-
-=item * Parse last update time
-
-=back
+Return value:  (any)
 
 =head1 SEE ALSO
 
@@ -265,7 +254,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
